import { ILogMethod, ISimpleBuilder } from 'webext-buildtools-builder-types';
import ChromeCrxBuilder from 'webext-buildtools-chrome-crx-builder';
import ChromeWebstoreBuilder from 'webext-buildtools-chrome-webstore-builder';
import DirReaderBuilder from 'webext-buildtools-dir-reader-mw';
import FirefoxAddonsBuilder from 'webext-buildtools-firefox-addons-builder';
import { AbstractCompositeBuilder, IAbstractSimpleBuilderClass, SubBuilderRecord } from 'webext-buildtools-utils';
import { IIntegratedOptions } from '../declarations/options';
import { IntegratedBuildResult } from './buildResult';
/**
 * ISimpleBuilder wrapper around sign-addon package
 */
export declare class IntegratedBuilder extends AbstractCompositeBuilder<IIntegratedOptions, IntegratedBuildResult> implements ISimpleBuilder<IntegratedBuildResult> {
    protected readonly _dirReader: SubBuilderRecord<this, DirReaderBuilder>;
    protected readonly _firefoxAddons: SubBuilderRecord<this, FirefoxAddonsBuilder>;
    protected readonly _chromeCrx: SubBuilderRecord<this, ChromeCrxBuilder>;
    protected readonly _chromeWebstore: SubBuilderRecord<this, ChromeWebstoreBuilder>;
    constructor(options: IIntegratedOptions, logMethod?: ILogMethod, stopOnWarning?: boolean, stopOnError?: boolean);
    getTargetName(): string;
    setInputDirPath(dirPath: string): this;
    /**
     * Packed extension dir
     * options.zipOptions.zipOutPath should be specified
     * Result asset: zipFile
     */
    requireZip(file?: boolean, buffer?: boolean): this;
    /**
     * Manifest object read from extension dir
     * Result asset: manifest
     */
    requireManifest(): this;
    /**
     * Extension packed to crx file and signed using your private key for offline distribution
     * options.chromeCrx.crxFilePath should be specified
     * Result asset: signedCrxFile
     */
    requireSignedCrx(file?: boolean, buffer?: boolean): this;
    /**
     * generates an updateXML for extensions hosted not on Chrome Web Store
     * This xml is used as response at url, specified in manifest's 'update_url' key
     * @see https://developer.chrome.com/apps/autoupdate
     * options.chromeCrx.updateXml:
     *      codebaseUrl,
     *      privateKey or privateKeyFilePath
     * should be specified
     * Result asset: signedCrxUpdateXmlFile
     */
    requireSignedCrxUpdateXml(file?: boolean, buffer?: boolean): this;
    /**
     * Upload/publish extension to Chrome Webstore
     * options.chromeWebstore:
     *      extensionId,
     *      upload
     * should be specified
     * Result asset: chromeWebstoreUploadedExt, chromeWebstorePublishedExt
     */
    requireChromeWebstoreDeploy(upload?: boolean, publish?: boolean): this;
    /**
     * Download published crx file from Chrome Webstore, normally used with requireChromeWebstoreDeploy()
     * options.chromeWebstore.downloadCrx should be specified
     * Result asset: chromeWebstorePublishedCrxFile
     */
    requireChromeWebstorePublishedCrx(file?: boolean, buffer?: boolean): this;
    /**
     * options.firefoxAddons.api and options.firefoxAddons.deploy should be specified
     * Result asset: firefoxAddonsDeployedExtStoreId
     */
    requireFirefoxAddonsDeploy(): this;
    /**
     * options.firefoxAddons.api and options.firefoxAddons.signXpi.xpiOutPath should be specified
     * Result asset: firefoxAddonsSignedExtStoreId, firefoxAddonsSignedXpiFile
     */
    requireFirefoxAddonsSignedXpi(file?: boolean, buffer?: boolean): this;
    protected requireAsset<TBuilder extends ISimpleBuilder<any>>(subBuilderRec: SubBuilderRecord<this, TBuilder>, doRequire: (builder: TBuilder) => any, 
    /**
     * mapping for saving sub builder assets to composite builder result
     * key: sub builder asset key, value: composite builder asset key
     */
    subBuilderToCompositeMapping?: {
        [subBuilderAssetKey: string]: string;
    }): this;
    protected createAbstractSimpleBuilder<TBuilder extends ISimpleBuilder<any>, TOptions>(builderConstructor: IAbstractSimpleBuilderClass<TBuilder, TOptions>, options: TOptions): TBuilder;
    protected createBuildResult(): IntegratedBuildResult;
    protected passOnDirReaderResult(): void;
}
