"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegratedBuilder = void 0;
const webext_buildtools_chrome_crx_builder_1 = require("webext-buildtools-chrome-crx-builder");
const webext_buildtools_chrome_webstore_builder_1 = require("webext-buildtools-chrome-webstore-builder");
const webext_buildtools_dir_reader_mw_1 = require("webext-buildtools-dir-reader-mw");
const webext_buildtools_firefox_addons_builder_1 = require("webext-buildtools-firefox-addons-builder");
const webext_buildtools_utils_1 = require("webext-buildtools-utils");
const buildResult_1 = require("./buildResult");
// noinspection JSUnusedGlobalSymbols
/**
 * ISimpleBuilder wrapper around sign-addon package
 */
class IntegratedBuilder extends webext_buildtools_utils_1.AbstractCompositeBuilder {
    constructor(options, logMethod, stopOnWarning = true, stopOnError = true) {
        super(options, logMethod, stopOnWarning, stopOnError);
        this._dirReader = this.addBuilder(webext_buildtools_dir_reader_mw_1.default.TARGET_NAME, this._options.zipOptions
            ? this.createAbstractSimpleBuilder(webext_buildtools_dir_reader_mw_1.default, this._options.zipOptions)
            : null, 100);
        this.passOnDirReaderResult();
        this._chromeCrx = this.addBuilder(webext_buildtools_chrome_crx_builder_1.default.TARGET_NAME, this._options.chromeCrx
            ? this.createAbstractSimpleBuilder(webext_buildtools_chrome_crx_builder_1.default, this._options.chromeCrx)
            : null, 200);
        this._firefoxAddons = this.addBuilder(webext_buildtools_firefox_addons_builder_1.default.TARGET_NAME, this._options.firefoxAddons
            ? this.createAbstractSimpleBuilder(webext_buildtools_firefox_addons_builder_1.default, this._options.firefoxAddons)
            : null, 300);
        this._chromeWebstore = this.addBuilder(webext_buildtools_chrome_webstore_builder_1.default.TARGET_NAME, this._options.chromeWebstore
            ? this.createAbstractSimpleBuilder(webext_buildtools_chrome_webstore_builder_1.default, this._options.chromeWebstore)
            : null, 400);
    }
    getTargetName() {
        return 'integrated-builder';
    }
    setInputDirPath(dirPath) {
        if (this._dirReader.builder) {
            this._dirReader.builder.setInputDirPath(dirPath);
        }
        return this;
    }
    // noinspection JSUnusedGlobalSymbols
    /**
     * Packed extension dir
     * options.zipOptions.zipOutPath should be specified
     * Result asset: zipFile
     */
    requireZip(file = true, buffer = false) {
        if (!file && !buffer) {
            throw new Error('Nor file or buffer is required');
        }
        if (file) {
            this.requireAsset(this._dirReader, b => b.requireZipFile(), { zipFile: 'zipFile' });
        }
        if (buffer) {
            this.requireAsset(this._dirReader, b => b.requireZipBuffer(), { zipBuffer: 'zipBuffer' });
        }
        return this;
    }
    // noinspection JSUnusedGlobalSymbols
    /**
     * Manifest object read from extension dir
     * Result asset: manifest
     */
    requireManifest() {
        return this.requireAsset(this._dirReader, b => b.requireManifest(), { manifest: 'manifest' });
    }
    // noinspection JSUnusedGlobalSymbols
    /**
     * Extension packed to crx file and signed using your private key for offline distribution
     * options.chromeCrx.crxFilePath should be specified
     * Result asset: signedCrxFile
     */
    requireSignedCrx(file = true, buffer = false) {
        if (!file && !buffer) {
            throw new Error('Nor file or buffer is required');
        }
        if (file) {
            this.requireAsset(this._chromeCrx, b => b.requireCrxFile(), { crxBuffer: 'signedCrxBuffer' });
        }
        if (buffer) {
            this.requireAsset(this._chromeCrx, b => b.requireCrxBuffer(), { crxFile: 'signedCrxFile' });
        }
        this.requireAsset(this._dirReader, b => b.requireZipBuffer());
        return this;
    }
    // noinspection JSUnusedGlobalSymbols
    /**
     * generates an updateXML for extensions hosted not on Chrome Web Store
     * This xml is used as response at url, specified in manifest's 'update_url' key
     * @see https://developer.chrome.com/apps/autoupdate
     * options.chromeCrx.updateXml:
     *      codebaseUrl,
     *      privateKey or privateKeyFilePath
     * should be specified
     * Result asset: signedCrxUpdateXmlFile
     */
    requireSignedCrxUpdateXml(file = true, buffer = false) {
        if (!file && !buffer) {
            throw new Error('Nor file or buffer is required');
        }
        if (file) {
            this.requireAsset(this._chromeCrx, b => b.requireUpdateXmlFile(), { updateXmlFile: 'signedCrxUpdateXmlFile' });
        }
        if (buffer) {
            this.requireAsset(this._chromeCrx, b => b.requireUpdateXmlBuffer(), { updateXmlBuffer: 'signedCrxUpdateXmlBuffer' });
        }
        this.requireAsset(this._dirReader, b => b.requireManifest());
        return this;
    }
    // noinspection JSUnusedGlobalSymbols
    /**
     * Upload/publish extension to Chrome Webstore
     * options.chromeWebstore:
     *      extensionId,
     *      upload
     * should be specified
     * Result asset: chromeWebstoreUploadedExt, chromeWebstorePublishedExt
     */
    requireChromeWebstoreDeploy(upload = true, publish = true) {
        if (!upload && !publish) {
            throw new Error('Nor upload or publish is required');
        }
        if (upload) {
            this.requireAsset(this._chromeWebstore, b => b.requireUploadedExt(), { uploadedExt: 'chromeWebstoreUploadedExt' });
            this.requireAsset(this._dirReader, b => b.requireZipBuffer().requireManifest());
        }
        if (publish) {
            this.requireAsset(this._chromeWebstore, b => b.requirePublishedExt(), { publishedExt: 'chromeWebstorePublishedExt' });
        }
        return this;
    }
    // noinspection JSUnusedGlobalSymbols
    /**
     * Download published crx file from Chrome Webstore, normally used with requireChromeWebstoreDeploy()
     * options.chromeWebstore.downloadCrx should be specified
     * Result asset: chromeWebstorePublishedCrxFile
     */
    requireChromeWebstorePublishedCrx(file = true, buffer = false) {
        if (!file && !buffer) {
            throw new Error('Nor file or buffer is required');
        }
        if (file) {
            this.requireAsset(this._chromeWebstore, b => b.requirePublishedCrxFile(), { publishedCrxFile: 'chromeWebstorePublishedCrxFile' });
        }
        if (buffer) {
            this.requireAsset(this._chromeWebstore, b => b.requirePublishedCrxBuffer(), { publishedCrxBuffer: 'chromeWebstorePublishedCrxBuffer' });
        }
        return this;
    }
    // noinspection JSUnusedGlobalSymbols
    /**
     * options.firefoxAddons.api and options.firefoxAddons.deploy should be specified
     * Result asset: firefoxAddonsDeployedExtStoreId
     */
    requireFirefoxAddonsDeploy() {
        this.requireAsset(this._firefoxAddons, b => b.requireDeployedExt(), { deployedExtStoreId: 'firefoxAddonsDeployedExtStoreId' });
        this.requireAsset(this._dirReader, b => b.requireZipBuffer().requireManifest());
        return this;
    }
    // noinspection JSUnusedGlobalSymbols
    /**
     * options.firefoxAddons.api and options.firefoxAddons.signXpi.xpiOutPath should be specified
     * Result asset: firefoxAddonsSignedExtStoreId, firefoxAddonsSignedXpiFile
     */
    requireFirefoxAddonsSignedXpi(file = true, buffer = false) {
        if (!file && !buffer) {
            throw new Error('Nor file or buffer is required');
        }
        if (file) {
            this.requireAsset(this._firefoxAddons, b => b.requireSignedXpiFile(), { signedXpiFile: 'firefoxAddonsSignedXpiFile' });
        }
        if (buffer) {
            this.requireAsset(this._firefoxAddons, b => b.requireSignedXpiBuffer(), { signedXpiBuffer: 'firefoxAddonsSignedXpiBuffer' });
        }
        this.requireAsset(this._dirReader, b => b.requireZipBuffer().requireManifest());
        return this;
    }
    requireAsset(subBuilderRec, doRequire, 
    /**
     * mapping for saving sub builder assets to composite builder result
     * key: sub builder asset key, value: composite builder asset key
     */
    subBuilderToCompositeMapping) {
        if (!subBuilderRec.builder) {
            throw new Error(subBuilderRec.targetName + ' sub builder is not initialized due to missed options');
        }
        doRequire(subBuilderRec.builder);
        if (subBuilderToCompositeMapping) {
            for (const subBuilderAssetKey of Object.keys(subBuilderToCompositeMapping)) {
                subBuilderRec.assetsRequiredForCompositeResult.set(subBuilderAssetKey, subBuilderToCompositeMapping[subBuilderAssetKey]);
            }
        }
        subBuilderRec.active = true;
        return this;
    }
    createAbstractSimpleBuilder(builderConstructor, options) {
        const logMethod = this._logWrapper.logMethod
            ? (0, webext_buildtools_utils_1.logMethodProxy)(this._logWrapper.logMethod, { msgPrefix: builderConstructor.TARGET_NAME + ': ' })
            : undefined;
        return new builderConstructor(options, logMethod);
    }
    // noinspection JSMethodCanBeStatic, JSUnusedGlobalSymbols
    createBuildResult() {
        return new buildResult_1.IntegratedBuildResult();
    }
    passOnDirReaderResult() {
        this._dirReader.onComplete((subBuilder, buildResult) => {
            const srcAssets = buildResult.getAssets();
            (0, webext_buildtools_utils_1.passOnAsset)(srcAssets.manifest)
                .to(this._firefoxAddons, (b, a) => b.setInputManifest(a))
                .to(this._chromeCrx, (b, a) => b.setInputManifest(a))
                .to(this._chromeWebstore, (b, a) => b.setInputManifest(a));
            (0, webext_buildtools_utils_1.passOnAsset)(srcAssets.zipBuffer)
                .to(this._firefoxAddons, (b, a) => b.setInputBuffer(a))
                .to(this._chromeCrx, (b, a) => b.setInputZipBuffer(a))
                .to(this._chromeWebstore, (b, a) => b.setInputZipBuffer(a));
        });
    }
}
exports.IntegratedBuilder = IntegratedBuilder;
//# sourceMappingURL=builder.js.map